@@ -23,7 +23,7 @@ from custodian import Custodian
 from custodian.vasp.handlers import VaspErrorHandler, AliasingErrorHandler, \
     MeshSymmetryErrorHandler, UnconvergedErrorHandler, MaxForceErrorHandler, PotimErrorHandler, \
     FrozenJobErrorHandler, NonConvergingErrorHandler, PositiveEnergyErrorHandler, \
-    WalltimeHandler, StdErrHandler, DriftErrorHandler
+    WalltimeHandler, StdErrHandler, DriftErrorHandler, LargeSigmaHandler, IncorrectSmearingHandler, ScanMetalHandler
 from custodian.vasp.jobs import VaspJob, VaspNEBJob
 from custodian.vasp.validators import VasprunXMLValidator, VaspFilesValidator
 
@@ -99,12 +99,18 @@ class RunVaspCustodian(FiretaskBase):
 
         handler_groups = {
             "default": [VaspErrorHandler(), MeshSymmetryErrorHandler(), UnconvergedErrorHandler(),
-                        NonConvergingErrorHandler(),PotimErrorHandler(),
-                        PositiveEnergyErrorHandler(), FrozenJobErrorHandler(), StdErrHandler()],
+                        NonConvergingErrorHandler(), PotimErrorHandler(),
+                        PositiveEnergyErrorHandler(), FrozenJobErrorHandler(), StdErrHandler(),
+                        LargeSigmaHandler(), IncorrectSmearingHandler()],
             "strict": [VaspErrorHandler(), MeshSymmetryErrorHandler(), UnconvergedErrorHandler(),
-                       NonConvergingErrorHandler(),PotimErrorHandler(),
+                       NonConvergingErrorHandler(), PotimErrorHandler(),
                        PositiveEnergyErrorHandler(), FrozenJobErrorHandler(),
-                       StdErrHandler(), AliasingErrorHandler(), DriftErrorHandler()],
+                       StdErrHandler(), AliasingErrorHandler(), DriftErrorHandler(), LargeSigmaHandler(), 
+                       IncorrectSmearingHandler()],
+            "scan": [VaspErrorHandler(), MeshSymmetryErrorHandler(), UnconvergedErrorHandler(),
+                     NonConvergingErrorHandler(), PotimErrorHandler(),
+                     PositiveEnergyErrorHandler(), FrozenJobErrorHandler(), StdErrHandler(),
+                     LargeSigmaHandler(), IncorrectSmearingHandler(), ScanMetalHandler()],
             "md": [VaspErrorHandler(), NonConvergingErrorHandler()],
             "no_handler": []
             }
